@@ -38,7 +38,7 @@
  *
  * Since: 1.0.0
  */
-#define GGANDIVA_VERSION_MAJOR (20)
+#define GGANDIVA_VERSION_MAJOR (21)
 
 /**
  * GGANDIVA_VERSION_MINOR:
@@ -110,6 +110,15 @@
 #  define GGANDIVA_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GGANDIVA_VERSION_21_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 21.0.0
+ */
+#define GGANDIVA_VERSION_21_0 G_ENCODE_VERSION(21, 0)
+
 /**
  * GGANDIVA_VERSION_20_0:
  *
@@ -424,6 +433,20 @@
 
 #define GGANDIVA_AVAILABLE_IN_ALL GGANDIVA_EXTERN
 
+#if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_21_0
+#  define GGANDIVA_DEPRECATED_IN_21_0               GGANDIVA_DEPRECATED
+#  define GGANDIVA_DEPRECATED_IN_21_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
+#else
+#  define GGANDIVA_DEPRECATED_IN_21_0
+#  define GGANDIVA_DEPRECATED_IN_21_0_FOR(function)
+#endif
+
+#if GGANDIVA_VERSION_MAX_ALLOWED < GGANDIVA_VERSION_21_0
+#  define GGANDIVA_AVAILABLE_IN_21_0 GGANDIVA_EXTERN GGANDIVA_UNAVAILABLE(21, 0)
+#else
+#  define GGANDIVA_AVAILABLE_IN_21_0 GGANDIVA_EXTERN
+#endif
+
 #if GGANDIVA_VERSION_MIN_REQUIRED >= GGANDIVA_VERSION_20_0
 #  define GGANDIVA_DEPRECATED_IN_20_0               GGANDIVA_DEPRECATED
 #  define GGANDIVA_DEPRECATED_IN_20_0_FOR(function) GGANDIVA_DEPRECATED_FOR(function)
